searchData={"content_type":"text/markdown","items":[{"doc":"A module to maintain a tree of the structure\n\n```elixir\n%Node{ key: ..., value: ..., children: [%TreeMap{},...]}\n```\n\nand functions to traverse such a tree.\n\n#","ref":"TreeMap.html","title":"TreeMap","type":"module"},{"doc":"```elixir\nroot =\n TreeMap.new(\"1\", \"Root\")\n |> TreeMap.add_child(\"1.1\", \"Sub One\", [TreeMap.new(\"1.1.1\", \"SomeSubSub\")])\n |> TreeMap.add_child(\"1.2\", \"Sub Two\", [TreeMap.new(\"1.2.1\", \"Some other SubSub\")])\n\nexpected = [\"1\", \"1.1\", \"1.1.1\", \"1.2\", \"1.2.1\"]\n\nreceived =\n TreeMap.transduce(root, [], fn a, x -> a ++ [x] end, fn n, acc -> [n | acc] end)\n |> Enum.map(& &1.key)\n\nassert expected == received\n```","ref":"TreeMap.html#module-examples","title":"Examples - TreeMap","type":"module"},{"doc":"Prepend an exisitng child to the children of this node.\n\n#","ref":"TreeMap.html#add_child/2","title":"TreeMap.add_child/2","type":"function"},{"doc":"iex> child = TreeMap.new(\"0\", \"I exist\")\n    iex> TreeMap.new(\"1\", \"Root\") |> TreeMap.add_child(child)\n    %TreeMap.Node{key: \"1\", value: \"Root\", children: [%TreeMap.Node{key: \"0\", value: \"I exist\"}]}","ref":"TreeMap.html#add_child/2-example","title":"Example: - TreeMap.add_child/2","type":"function"},{"doc":"Prepend a new child to the children of this node.\n\n#","ref":"TreeMap.html#add_child/4","title":"TreeMap.add_child/4","type":"function"},{"doc":"iex> TreeMap.new(\"1\", \"Root\") |> TreeMap.add_child(\"1.1\", \"Sub One\")\n    %TreeMap.Node{key: \"1\", value: \"Root\", children: [%TreeMap.Node{key: \"1.1\", value: \"Sub One\"}]}","ref":"TreeMap.html#add_child/4-example","title":"Example: - TreeMap.add_child/4","type":"function"},{"doc":"Return the children of this node.","ref":"TreeMap.html#children/1","title":"TreeMap.children/1","type":"function"},{"doc":"Kill all RootServers.","ref":"TreeMap.html#drop_all/0","title":"TreeMap.drop_all/0","type":"function"},{"doc":"Find a node by it's key or returns `false` in all root nodes.","ref":"TreeMap.html#find/1","title":"TreeMap.find/1","type":"function"},{"doc":"Find a node by it's key or returns `false` in a given tree.","ref":"TreeMap.html#find/2","title":"TreeMap.find/2","type":"function"},{"doc":"List all root nodes from all RootServers.","ref":"TreeMap.html#list_roots/0","title":"TreeMap.list_roots/0","type":"function"},{"doc":"#","ref":"TreeMap.html#new/3","title":"TreeMap.new/3","type":"function"},{"doc":"iex> TreeMap.new()\n    %TreeMap.Node{}\n\n    iex> TreeMap.new(123, \"hundretandtwentythree\")\n    %TreeMap.Node{ key: 123, value: \"hundretandtwentythree\"}","ref":"TreeMap.html#new/3-examples","title":"Examples - TreeMap.new/3","type":"function"},{"doc":"Start a root_node for the given `%Node{}`.","ref":"TreeMap.html#start_root_node/1","title":"TreeMap.start_root_node/1","type":"function"},{"doc":"Create a Node and start a RootServer for it.","ref":"TreeMap.html#start_root_node/2","title":"TreeMap.start_root_node/2","type":"function"},{"doc":"Traverse the tree map and apply the given function to each node \n  and a reducer-function to it's children.\n\n#","ref":"TreeMap.html#transduce/4","title":"TreeMap.transduce/4","type":"function"},{"doc":"iex> root = TreeMap.new(\"1\", \"Root\") \n    ...>        |> TreeMap.add_child(\"1.1\", \"Sub One\", [TreeMap.new(\"1.1.1\", \"SomeSubSub\")]) \n    ...>        |> TreeMap.add_child(\"1.2\", \"Sub Two\", [TreeMap.new(\"1.2.1\", \"Some other SubSub\")])\n    ...> TreeMap.transduce(root, 38, fn a, x -> a + Enum.count(x.children) end, fn x, acc -> acc + x end)\n    42\n\n    iex> root = TreeMap.new(\"1\", \"Root\") \n    ...>        |> TreeMap.add_child(\"1.1\", \"Sub One\", [TreeMap.new(\"1.1.1\", \"SomeSubSub\")]) \n    ...>        |> TreeMap.add_child(\"1.2\", \"Sub Two\", [TreeMap.new(\"1.2.1\", \"Some other SubSub\")])\n    ...> TreeMap.transduce(root, [], fn a, x -> a ++ [x.value] end, fn n, acc -> [n | acc] end) \n    [\"Root\", \"Sub One\", \"SomeSubSub\", \"Sub Two\", \"Some other SubSub\"]\n\n    iex> root = TreeMap.new(\"1\", \"Root\") \n    ...>        |> TreeMap.add_child(\"1.1\", \"Sub One\", [TreeMap.new(\"1.1.1\", \"SomeSubSub\")]) \n    ...>        |> TreeMap.add_child(\"1.2\", \"Sub Two\", [TreeMap.new(\"1.2.1\", \"Some other SubSub\")])\n    ...> TreeMap.transduce(root, [], fn a, x -> a ++ [x] end, fn n, acc -> [n | acc] end) \n    ...> |> Enum.map(& &1.key)\n    [\"1\", \"1.1\", \"1.1.1\", \"1.2\", \"1.2.1\"]","ref":"TreeMap.html#transduce/4-example","title":"Example: - TreeMap.transduce/4","type":"function"},{"doc":"Traverse the tree map and apply the given function to each node.\n\n#","ref":"TreeMap.html#traverse/2","title":"TreeMap.traverse/2","type":"function"},{"doc":"iex> root = TreeMap.new(\"1\", \"Root\") |> TreeMap.add_child(\"1.1\", \"Sub One\") |> TreeMap.add_child(\"1.2\", \"Sub Two\")\n    ...> TreeMap.traverse(root, fn x -> x.key end)\n    [\"1\", [\"1.1\", [], \"1.2\", []]]","ref":"TreeMap.html#traverse/2-example","title":"Example: - TreeMap.traverse/2","type":"function"},{"doc":"Retreive the value of a given root node.","ref":"TreeMap.html#value/1","title":"TreeMap.value/1","type":"function"},{"doc":"`Node` can be used as a simple structure, representing a node in a tree\nor as a GenServer to store the Node structure.\n\nNode GenServer are supervised by `TreeMap.RootServer` and should \nbe started and stopped throug `TreeMap` module.","ref":"TreeMap.Node.html","title":"TreeMap.Node","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"TreeMap.Node.html#child_spec/1","title":"TreeMap.Node.child_spec/1","type":"function"},{"doc":"Return the `%Node{}` struct of this process.","ref":"TreeMap.Node.html#node/1","title":"TreeMap.Node.node/1","type":"function"},{"doc":"","ref":"TreeMap.Node.html#start_link/2","title":"TreeMap.Node.start_link/2","type":"function"},{"doc":"Returns the value of the `%Node{}` struct of this process.","ref":"TreeMap.Node.html#value/1","title":"TreeMap.Node.value/1","type":"function"},{"doc":"A server to maintain a list of root nodes as a DynamicSupervisor.\n\n\nDon't call this module directly. Use the `TreeMap` module instead.\n\n#","ref":"TreeMap.RootServer.html","title":"TreeMap.RootServer","type":"module"},{"doc":"iex> TreeMap.list_roots()\n    [%Node{}, ...]\n\n    iex> TreeMap.find(\"key\")\n    %Node{}\n\n    iex> TreeMap.drop_all()\n    [:ok, ...]","ref":"TreeMap.RootServer.html#module-examples","title":"Examples - TreeMap.RootServer","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"TreeMap.RootServer.html#child_spec/1","title":"TreeMap.RootServer.child_spec/1","type":"function"},{"doc":"Stop all children.","ref":"TreeMap.RootServer.html#drop_all/0","title":"TreeMap.RootServer.drop_all/0","type":"function"},{"doc":"Return the root node of each child.","ref":"TreeMap.RootServer.html#list_roots/0","title":"TreeMap.RootServer.list_roots/0","type":"function"},{"doc":"Start a new root node as supervised child.","ref":"TreeMap.RootServer.html#start_child/1","title":"TreeMap.RootServer.start_child/1","type":"function"},{"doc":"Start the DynamicSupervisor as a singleton.","ref":"TreeMap.RootServer.html#start_link/1","title":"TreeMap.RootServer.start_link/1","type":"function"},{"doc":"# README","ref":"readme.html","title":"README","type":"extras"},{"doc":"[![Elixir CI](https://github.com/iboard/tree_map/actions/workflows/elixir.yml/badge.svg)](https://github.com/iboard/tree_map/actions/workflows/elixir.yml)\nA module to maintain a tree of the structure\n\n```elixir\n  %TreeMap{ key: ..., value: ..., children: [%TreeMap{},...]}\n```\n\nand functions to traverse such a tree.\n\n#","ref":"readme.html#treemap-0-1","title":"TreeMap 0.1 - README","type":"extras"},{"doc":"```elixir\n root =\n   TreeMap.new(\"1\", \"Root\")\n   |> TreeMap.add_child(\"1.1\", \"Sub One\", [TreeMap.new(\"1.1.1\", \"SomeSubSub\")])\n   |> TreeMap.add_child(\"1.2\", \"Sub Two\", [TreeMap.new(\"1.2.1\", \"Some other SubSub\")])\n\n expected = [\"1\", \"1.1\", \"1.1.1\", \"1.2\", \"1.2.1\"]\n\n received =\n   TreeMap.transduce(root, [], fn a, x -> a ++ [x] end, fn n, acc -> [n | acc] end)\n   |> Enum.map(& &1.key)\n\n assert expected == received\n```\n\n#","ref":"readme.html#examples","title":"Examples - README","type":"extras"},{"doc":"`TreeMap.RootServer` is a `DynamicSupervisor` that can be used to maintain a tree of `TreeMap` nodes.\n\n##","ref":"readme.html#rootserver","title":"RootServer - README","type":"extras"},{"doc":"iex> TreeMap.list_roots()\n    [%Node{}, ...]\n\n    iex> TreeMap.find(\"key\")\n    %Node{}\n\n    iex> TreeMap.drop_all()\n    [:ok, ...]","ref":"readme.html#examples","title":"Examples - README","type":"extras"},{"doc":"[Available in Hex](https://hex.pm/packages/tree_map), the package can be \ninstalled by adding `tree_map` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:tree_map, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - README","type":"extras"},{"doc":"# LICENSE\n\n```\n   Copyright 2023 Andreas Altendorfer  \n\n   Licensed under the Apache License, Version 2.0 (the \"License\");\n   you may not use this file except in compliance with the License.\n   You may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\n   Unless required by applicable law or agreed to in writing, software\n   distributed under the License is distributed on an \"AS IS\" BASIS,\n   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n   See the License for the specific language governing permissions and\n   limitations under the License.\n\n```","ref":"license.html","title":"LICENSE","type":"extras"},{"doc":"# Changelog","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"","ref":"changelog.html#2023-09-15-initial-version-0-1-0","title":"2023-09-15 Initial version 0.1.0 - Changelog","type":"extras"}]}